// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import cn from 'classnames'

const defaultStyles = {
  container: '',
  title: '',
  subtitle: '',
}

const Hero = ({
  title,
  subtitle,
  children,
  className,
  theme,
}: {
  title: string,
  subtitle: string,
  children?: any,
  className?: string,
  theme: { [key: string]: string },
}) => (
  <section className={cn('hero', className)}>
    <div className="hero-body">
      <div className={cn('container', theme.container)}>
        <h1 className={cn('title', theme.title)}>
          {title}
        </h1>
        <h2 className={cn('subtitle', theme.subtitle)}>
          {subtitle}
        </h2>
        {children}
      </div>
    </div>
  </section>
)

Hero.defaultProps = {
  children: null,
  className: null,
}

export default themr('Hero', defaultStyles, { composeTheme: 'softly' })(Hero)
