// @flow

import React from 'react'
import cn from 'classnames'
import { themr } from 'react-css-themr'
import Input from 'rebulma/lib/Input'
import Button from 'rebulma/lib/Button'

const defaultStyles = {
  header: '',
  input: '',
  callToAction: '',
}

const themeConfig = {
  vertical: {
    root: '',
    form: '',
    input: 'w-100',
    callToAction: 'w-100',
  },
  horizontal: {
    root: '',
    form: 'flex items-center',
    input: 'flex-auto',
    callToAction: 'flex-none',
  },
}

const OptIn = ({
  isHorizontal = false,
  header,
  action,
  secret,
  callToAction,
  nameLabel,
  name,
  onNameChange,
  emailLabel,
  email,
  onEmailChange,
  className,
  theme,
}: {
  isHorizontal?: boolean,
  header?: string,
  action: string,
  secret: string,
  callToAction: string,
  emailLabel?: string,
  email: string,
  onEmailChange: (email: string) => void,
  nameLabel?: string,
  name: string,
  onNameChange: (name: string) => void,
  className?: string,
  theme: { [key: string]: string },
}) => {
  const styleName = isHorizontal ? 'horizontal' : 'vertical'
  const _theme = themeConfig[styleName]
  return (
    <div className={className}>
      {!!header && <h2 className={theme.header}>{header}</h2>}
      <form
        className={_theme.form}
        action={action}
        method="post"
        target="_blank"
      >
        {typeof name === 'string' &&
          <Input
            name="FNAME"
            id="mce-FNAME"
            className={cn(_theme.input, theme.input)}
            value={name}
            placeholder={nameLabel}
            onChange={(e) => {
              onNameChange(e.target.value)
            }}
          />}
        <Input
          type="email"
          name="EMAIL"
          id="mce-EMAIL"
          className={cn(_theme.input, theme.input)}
          value={email}
          placeholder={emailLabel}
          onChange={(e) => {
            onEmailChange(e.target.value)
          }}
        />
        <input
          className="dn"
          aria-hidden="true"
          type="text"
          name={secret}
          tabIndex="-1"
          value=""
        />
        <Button className={cn(_theme.callToAction, theme.callToAction)}>
          {callToAction}
        </Button>
      </form>
    </div>
  )
}

OptIn.defaultProps = {
  header: null,
  className: null,
  isHorizontal: false,
  nameLabel: 'Your Name',
  emailLabel: 'Your Email',
}

export default themr('OptIn', defaultStyles, { composeTheme: 'softly' })(OptIn)
