// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import cn from 'classnames'
import PricingTable from 'components/PricingTable'
import FAQ from 'components/FAQ'
import StandardList from 'components/StandardList'
import SmallList from 'components/SmallList'
import HorizontalSmallList from 'components/HorizontalSmallList'

const MyFaq = ({
  data,
  className,
  childrenTheme,
}: {
  data: Array<{ question: string, answer: string }>,
  className?: string,
  childrenTheme: { [key: string]: string },
}) => (
  <FAQ items={data} className={className} theme={childrenTheme} />
)

MyFaq.defaultProps = {
  className: null,
}

const defaultStyles = {
  root: '',
  title: '',
  subtitle: '',
  body: 'mw8 center',
  itemWrapper: 'w-100 w-third-ns pv2 ph2-ns',
  action: '',
}

function getComponent(type?: string = 'Standard'): any {
  return {
    Standard: StandardList,
    Small: SmallList,
    HorizontalSmall: HorizontalSmallList,
    PricingTable,
    FAQ: MyFaq,
  }[type]
}

const Section = ({
  section: {
    title,
    subtitle,
    type,
    useH1 = false,
    data = [],
    actions = [],
    backgroundImage,
    backgroundPosition = 'center',
    backgroundRepeat = 'no-repeat',
    backgroundOnMobile = true,
  } = {},
  theme,
  childrenTheme,
  Link,
  className,
}: {
  section?: TSection,
  theme: { [key: string]: string },
  childrenTheme: { [key: string]: string },
  Link: any,
  className?: string,
}) => {
  const Component = getComponent(type)
  const H = useH1 ? 'h1' : 'div'

  const style = !backgroundOnMobile && backgroundImage ? {
    backgroundImage: `url(${backgroundImage})`,
    backgroundRepeat,
    backgroundPosition,
  } : {}

  return (
    <div
      className={cn(theme.root, className)}
      style={style}
    >
      <H className={theme.title}>{title}</H>
      <div className={theme.subtitle}>{subtitle}</div>
      <Component
        className={theme.body}
        data={data}
        childrenTheme={childrenTheme}
        itemClassName={theme.itemWrapper}
      />
      <div className={theme.footer}>
        {actions.length > 0 && actions.map(action => (
          <div className="h3 tc mt2 mt3-ns">
            <Link
              className={cn('button', theme.action, { 'is-outlined': action.secondary })}
              to={action.href}
            >
              {action.label}
            </Link>
          </div>
        ))}
      </div>
    </div>
  )
}

Section.defaultProps = {
  callToAction: null,
  className: null,
  section: {},
}

export default themr('Section', defaultStyles, { composeTheme: 'softly' })(Section)
