// @flow

import React from 'react'
import Section from 'components/Section'

const Sections = ({
  sections,
  className,
  themes,
  Link,
}: {
  sections: Array<TSection>,
  className?: string,
  themes: Array<{
    id: string,
    theme: { [key: string]: string },
    childrenTheme: { [key: string]: string },
  }>,
  Link: any,
}) => {
  const keys = sections.map(x => x.id)
  const sectionMap = sections.reduce((acc, value) => ({
    ...acc,
    [value.id]: value,
  }), {})
  const themeMap = themes.reduce((acc, value) => ({
    ...acc,
    [value.id]: value,
  }), {})

  return (
    <div className={className}>
      {keys.map(key => (
        <Section
          key={key}
          section={sectionMap[key]}
          theme={themeMap[key].theme}
          childrenTheme={themeMap[key].childrenTheme}
          Link={Link}
        />
      ))}
    </div>
  )
}

Sections.defaultProps = {
  className: null,
}

export default Sections
