// @flow

import React from 'react'
import cn from 'classnames'
import { themr } from 'react-css-themr'
import Input from 'rebulma/lib/Input'
import Button from 'rebulma/lib/Button'

const defaultStyle = {
  root: '',
  title: 'title',
  subtitle: 'subtitle',
  leftWrapper: 'pa2 pa3-ns',
  rightWrapper: 'pa2 pa3-ns',
  imageUrl: '',
  imageCaption: 'tc',
}

const SideBySideHero = ({
  className,
  title,
  subtitle,
  subscribeText,
  imageUrl,
  imageCaption,
  theme,
}: {
  className?: string,
  title: string,
  subtitle: string,
  subscribeText: string,
  imageUrl: string,
  imageCaption: string,
  theme: { [key: string]: string },
}) => (
  <section className={cn('flex flex-wrap', className)}>
    <div className={cn('w-100 w-50-ns', theme.leftWrapper)}>
      <h1 className={theme.title}>
        {title}
      </h1>
      <h2 className={theme.subtitle}>
        {subtitle}
      </h2>
      <div className="flex-wrap">
        <Input
          className="w-100 flex-auto"
          name="email"
          type="email"
          placeholder="Your work email"
        />
        <Button className="w-100 is-primary">
          {subscribeText}
        </Button>
      </div>
    </div>
    <div className={cn('w-100 w-50-ns', theme.rightWrapper)}>
      <img
        src={imageUrl}
        alt={imageCaption}
        className={theme.image}
      />
      {!!imageCaption && (
        <div className={theme.imageCaption}>
          {imageCaption}
        </div>
      )}
    </div>
  </section>
)

SideBySideHero.defaultProps = {
  className: null,
}

export default themr('SideBySideHero', defaultStyle, { composeTheme: 'softly' })(SideBySideHero)
